TRAINING_PHASE = "train"
EVALUATION_PHASE = "eval"
PREDICTION_PHASE = "predict"